geowatch.utils.lightning\_ext.callbacks.auto\_resumer module
============================================================

.. automodule:: geowatch.utils.lightning_ext.callbacks.auto_resumer
   :members:
   :undoc-members:
   :show-inheritance:
